| Title: | Cuddy-Della Valle Index for Capturing the Instability in Time Series Data |
|---|---|
| Description: | Cuddy-Della valle index gives the degree of instability present in the data by accommodating the effect of a trend. The adjusted R squared value of the best fitted model is chosen. The index is obtained by multiplying the coefficient of variation with square root of one minus the adjusted R-squared value. This package has been developed using concept of Shankar et al. (2022)<doi:10.3389/fsufs.2023.1208898>. |
| Authors: | Dr. S. Vishnu Shankar [aut, cre], Dr. Ranjit Kumar Paul [aut], Dr. Md Yeasin [aut], Dr. Himadri Shekhar Roy [aut] |
| Maintainer: | Dr. S. Vishnu Shankar <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-12 05:58:07 UTC |
| Source: | https://github.com/cran/CDVI |
Cuddy-Della Valle Index for Capturing the Instability in Time Series Data.
CDVI(data, verbose = TRUE)CDVI(data, verbose = TRUE)
data |
Name of the data taken for the study |
verbose |
Logical. If TRUE, the function prints detailed information about its progress. Default is FALSE. |
CV, CDVI
1. Shankar, S. V., Chandel, A., Gupta, R. K., Sharma, S., Chand, H., Kumar, R., ... & Gowsar, S. N. (2023). Corrigendum: Exploring the dynamics of arrivals and prices volatility in onion (Allium cepa) using advanced time series techniques. Frontiers in Sustainable Food Systems, 7, 1290515. DOI: 10.3389/fsufs.2023.1208898
{ library(CDVI) Prices <- runif(15, min = 800, max = 1200) data <- data.frame(Prices) CDVI(data = data$Prices) }{ library(CDVI) Prices <- runif(15, min = 800, max = 1200) data <- data.frame(Prices) CDVI(data = data$Prices) }