Welcome to ClientVPS Mirrors

Help for package CDVI
Type: Package
Title: Cuddy-Della Valle Index for Capturing the Instability in Time Series Data
Version: 0.1.0
Author: Dr. S. Vishnu Shankar [aut, cre], Dr. Ranjit Kumar Paul [aut], Dr. Md Yeasin [aut], Dr. Himadri Shekhar Roy [aut]
Maintainer: Dr. S. Vishnu Shankar <S.vishnushankar55@gmail.com>
Description: Cuddy-Della valle index gives the degree of instability present in the data by accommodating the effect of a trend. The adjusted R squared value of the best fitted model is chosen. The index is obtained by multiplying the coefficient of variation with square root of one minus the adjusted R-squared value. This package has been developed using concept of Shankar et al. (2022)<doi:10.3389/fsufs.2023.1208898>.
License: GPL-3
Encoding: UTF-8
Imports: stats, base
NeedsCompilation: no
RoxygenNote: 7.3.1
Packaged: 2024-04-04 14:23:28 UTC; JARVIS
Repository: CRAN
Date/Publication: 2024-04-04 18:03:00 UTC

CDVI

Description

Cuddy-Della Valle Index for Capturing the Instability in Time Series Data.

Usage

CDVI(data, verbose = TRUE)

Arguments

data

Name of the data taken for the study

verbose

Logical. If TRUE, the function prints detailed information about its progress. Default is FALSE.

Value

CV, CDVI

References

1. Shankar, S. V., Chandel, A., Gupta, R. K., Sharma, S., Chand, H., Kumar, R., ... & Gowsar, S. N. (2023). Corrigendum: Exploring the dynamics of arrivals and prices volatility in onion (Allium cepa) using advanced time series techniques. Frontiers in Sustainable Food Systems, 7, 1290515. DOI: 10.3389/fsufs.2023.1208898

Examples

{
library(CDVI)
Prices <- runif(15, min = 800, max = 1200)
data <- data.frame(Prices)
CDVI(data = data$Prices)
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.